<?php
require_once 'lib/list_util.php';
require_once 'lib/utils.php';
require_once 'lib/vod/movie.php';

require_once 'Ulitka_vod_category.php';
require_once 'Ulitka_movie.php';
require_once 'Ulitka_movie_series.php';

class UlitkaApi
{
    private static function ulitka_get_document($url, &$plugin_cookies)
    {
        $ch =   array
                (
                    CURLOPT_COOKIEJAR       => '/tmp/ulitka.tv.cookies',
                    CURLOPT_COOKIEFILE      => '/tmp/ulitka.tv.cookies',
                    CURLOPT_FOLLOWLOCATION  => true,
                );
        $doc = HD::http_get_document($url, $ch);

        return $doc;
    }
    
    private static function ulitka_post_document($url, $post_data, &$plugin_cookies)
    {
        $ch =   array
                (
                    CURLOPT_COOKIEJAR       => '/tmp/ulitka.tv.cookies',
                    CURLOPT_COOKIEFILE      => '/tmp/ulitka.tv.cookies',
                    CURLOPT_FOLLOWLOCATION  => true,
                    CURLOPT_POST            => true,
                    CURLOPT_POSTFIELDS      => $post_data,
                );
        $doc = HD::http_get_document($url, $ch);

        return $doc;
    }
    ////////////////////////////////////////////////////////////////////////////////////
    //
    //              Authorization
    //
    public static function Login(&$vip, &$plugin_cookies, $username = false, $password = false)
    {
        $vip = 0;
        if (!$username || !$password)
        {
            if (!isset($plugin_cookies->username) || !isset($plugin_cookies->password))    
                return 0;
                
            $username = $plugin_cookies->username;
            $password = $plugin_cookies->password;
        }
        $ch =   array
                (
                    CURLOPT_COOKIEJAR       => '/tmp/ulitka.tv.cookies',
                );
        $doc = HD::http_get_document('http://www.ulitka.tv/dune/token.php', $ch);
        
        $post_data = "username=" . $username . "&passwd=" . $password . "&remember=yes&option=com_user&task=login&return=L2R1bmUvaW5kZXgueG1s&$doc=1";
        $ch =   array
                (
                    CURLOPT_COOKIEJAR       => '/tmp/ulitka.tv.cookies',
                    CURLOPT_COOKIEFILE      => '/tmp/ulitka.tv.cookies',
                    CURLOPT_POST            => true,
                    CURLOPT_POSTFIELDS      => $post_data,
                    CURLOPT_FOLLOWLOCATION  => true,
                );
        
        try
        {
            $doc = HD::http_get_document('http://www.ulitka.tv/component/user/', $ch);
        }
        catch(Exception $e)
        {
            hd_print("Connection error!!!");
            return 0;
        }
        
        $xml = simplexml_load_string($doc);
        if ($xml === false)
            return 0;

        if ($xml->getName() !== 'dune')
            return 0;
        
        $uid = 0;
        foreach ($xml->children() as $item)
        {
            if ($item->getName() != 'item')
                continue;
                
            if (isset($item->uid) && isset($item->vip))
            {
                $uid = intval($item->uid);
                $vip = intval($item->vip);
                break;
            }
        }
        
        return $uid;
    }
    ////////////////////////////////////////////////////////////////////////////////////
    //
    //              Sending play notifications to the server
    //
    public static function send_state($state, $uid, $cid, $pos, $plugins_cookies)
    {
        $post_data = "state=$state&uid=$uid&cid=$cid&current=$pos&total=0";
        
        self::ulitka_post_document('http://www.ulitka.tv/plugins/index2.php', $post_data, $plugins_cookies);
    }
    ////////////////////////////////////////////////////////////////////////////////////
    //
    //              VIDEO/AUDIO List
    //

    ////////////////////////////////////////////////////////////////////////////////////////////////
    private static function _encode_id($type, $ref, $name, $poster_url)
    {
        $id =   array
                (
                    'type'          => $type,
                    'ref'           => str_replace(UlitkaConfig::VOD_ROOT_URL, '', $ref),
                    'name'          => $name,
                    'poster_url'    => str_replace(UlitkaConfig::VOD_ROOT_URL, '', $poster_url),
                );
        $id = json_encode($id);
        return base64_encode($id);
    }
    
    public static function parse_season($season_url, $uid, &$description, &$genre, &$plugin_cookies)
    {
        try
        {
            $page = self::ulitka_get_document($season_url, $plugin_cookies);
        }
        catch(Exception $e)
        {
            hd_print("Connection error!!!");
            return array();
        }
        
        $xml = simplexml_load_string($page);
        if ($xml === false)
            return;

        if ($xml->getName() !== 'dune')
            return;
        
        $series = array();
        $n = 0;
        foreach ($xml->children() as $item)
        {
            if ($item->getName() != 'item')
                continue;
                
            if (intval($item->isFolder) === 1)
                continue;
                
            if (!isset($desc) && isset($item->plot))
                $desc = strval($item->plot);
            if (!isset($lgenre) && isset($item->genre))
                $lgenre = strval($item->genre);

            $episode = new UlitkaMovieSeries($n);

            $episode->name = strval($item->title);
            $episode->playback_url = strval($item->url) . "?version=4.3.132&id=$uid&target=dune";
            $episode->playback_url_is_stream_url = true;
            $episode->is_audio = false;
            $episode->uid = $uid;
            $episode->cid = strval($item->cid);
            $episode->watched = strval($item->watched);
            $episode->duration = strval($item->duration);

            array_push
            (
                $series,
                $episode
            );
            
            ++$n;
        }
        
        if (isset($desc))
            $description = $desc;
        else
            $description = '';

        if (isset($lgenre))
            $genre = $lgenre;
        else
            $genre = '';
            
        return $series;
    }
    
    public static function get_seasons($category_url, $uid, &$plugin_cookies)
    {
        try
        {
            $page = self::ulitka_get_document($category_url, $plugin_cookies);
        }
        catch(Exception $e)
        {
            hd_print("Connection error!!!");
            return array();
        }
        
        $xml = simplexml_load_string($page);
        if ($xml === false)
            return array();

        if ($xml->getName() !== 'dune')
            return array();

        $movies = array();
        foreach ($xml->children() as $item)
        {
            if ($item->getName() != 'item')
                continue;
                
            if ($item->url == UlitkaConfig::VOD_CATEGORIES_URL)
                continue;
            
            // get title
            $name = strval($item->title);

            // get reference
            $ref = strval($item->url);
            
            $poster_url = strval($item->thumbnailImage);
            
            // get id
            $id = self::_encode_id('season', $ref, $name, $poster_url);

            $movie =
                new ShortMovie
                    (
                        $id,
                        $name,
                        $ref,
                        $poster_url
                    );
            array_push
            (
                $movies,
                $movie
            );
        }
        
        return $movies;
    }
    
    public static function get_short_movie_info($movie_url, &$description, &$genre, &$plugin_cookies)
    {
        try
        {
            $page = self::ulitka_get_document($movie_url, $plugin_cookies);
        }
        catch(Exception $e)
        {
            hd_print("Connection error!!!");
            return array();
        }
        
        $xml = simplexml_load_string($page);
        if ($xml === false)
            return array();

        if ($xml->getName() !== 'dune' && $xml->getName() !== 'xbmc')
            return array();

        $movies = array();
        foreach ($xml->children() as $item)
        {
            if ($item->getName() != 'item')
                continue;
                
            if ($item->url == UlitkaConfig::VOD_CATEGORIES_URL)
                continue;
            
            $description = strip_tags(strval($item->plot));
            
            $genre = strval($item->genre);
            
            break;
        }
    }
    public static function get_short_movies_list($category_url, $doc, &$plugin_cookies)
    {
        if ($category_url)
        {
            try
            {
                $page = self::ulitka_get_document($category_url, $plugin_cookies);
            }
            catch(Exception $e)
            {
                hd_print("Connection error!!!");
                return array();
            }
        }
        else if ($doc)
        {
            $page = $doc;
        }
        else
        {
            return array();
        }
        
        $xml = simplexml_load_string($page);
        if ($xml === false)
            return array();

        if ($xml->getName() !== 'dune' && $xml->getName() !== 'xbmc')
            return array();

        $movies = array();
        foreach ($xml->children() as $item)
        {
            if ($item->getName() != 'item')
                continue;
                
            if ($item->url == UlitkaConfig::VOD_CATEGORIES_URL)
                continue;
            
            // get title
            $name = strval($item->title);

            // get reference
            $ref = strval($item->url);
            
            $poster_url = strval($item->thumbnailImage);

            // get id
            $type = isset($item->tvshowtitle) ? 'season' : 'movie';
            $id = self::_encode_id($type, $ref, $name, $poster_url);
            
            $movie =
                new ShortMovie
                    (
                        $id,
                        $name,
                        $ref,
                        $poster_url
                    );

            $movies[$id] = $movie;
        }
        
        return $movies;
    }
    ////////////////////////////////////////////////////////////////////////////////////
    //
    //              VIDEO/AUDIO Category List
    //

    private static function fill_categories($videos)
    {
        
        $category_list = array();

        $xml = simplexml_load_string($videos);
        
        if ($xml === false)
            return $category_list;

        if ($xml->getName() !== 'dune')
            return $category_list;

        foreach ($xml->children() as $item)
        {
            if ($item->getName() != 'item')
                continue;
                
            if ($item->url == UlitkaConfig::VOD_CATEGORIES_URL)
                continue;
            
            // get category id
            $category_id = strval($item->label);

            // get category title
            $category_name = strval($item->title);

            // get category view reference
            $category_ref = strval($item->url);
            
            // get image
            $image_url = strval($item->thumbnailImage);

            $cat =
                new UlitkaVodCategory
                    (
                        $category_id,
                        $category_name,
                        $category_ref,
                        $image_url
                    );

            $category_list[$category_id] = $cat;
        }
        
        return $category_list;
    }

    ///////////////////////////////////////////////////////////////////////
    public static function get_categories($plugin_cookies)
    {
        $category_url = UlitkaConfig::VOD_CATEGORIES_URL;

        $videos = array();
        
        try
        {
            $videos = self::ulitka_get_document($category_url, $plugin_cookies);
        }
        catch(Exception $e)
        {
            hd_print("Connection error!!!");
            return array();
        }
     
        // get list of genres
        return self::fill_categories($videos);
    }

    ////////////////////////////////////////////////////////////////////////////////////
    //
    //              get_movie_by_id
    //
    public static function get_movie_by_id($id, &$plugin_cookies)
    {
        $mid = base64_decode($id);
        $mid = json_decode($mid);
        return  new ShortMovie
                (
                    $id,
                    $mid->name,
                    UlitkaConfig::VOD_ROOT_URL . $mid->ref,
                    UlitkaConfig::VOD_ROOT_URL . $mid->poster_url
                );
    }
    public static function movie_is_season($id, &$plugin_cookies)
    {
        $mid = base64_decode($id);
        $mid = json_decode($mid);
        return $mid->type == 'season';
    }

    ////////////////////////////////////////////////////////////////////////////////////
    //
    //              VIDEO/AUDIO Search
    //
    public static function get_search_items($search_text, &$plugin_cookies)
    {
        $page = self::ulitka_post_document('http://www.ulitka.tv/dune/search.php', 'search=' . $search_text, $plugin_cookies);
        return self::get_short_movies_list(false, $page, $plugin_cookies);
    }
}

?>
