<?php

require_once 'lib/vod/movie.php';
require_once 'lib/utils.php';

class UlitkaSeason
{
    public $id;
    public $title;
    public $url;

    public function __construct($id, $url, $title)
    {
        $this->id = $id;
        $this->title = $title;
        $this->url = $url;
    }
}

class UlitkaMovie extends Movie implements UserInputHandler
{
    const ID = 'sv_movie';

    public $has_new_series = false;

    public $has_sub_view = false;
    public $sub_views = false;
    
    public $resume_off = false;
    private $series_idx = -1;
    private $pause_sent = false;
    private $last_pos = 0;
    
    public function __construct($id)
    {
        parent::__construct($id);
    }

    public function get_handler_id()
    { return self::ID; }

    public function add_episode($episode)
    {
        $this->series_list[] = $episode;
    }
    
    public function add_sub_view($sub_view)
    {
        $this->has_sub_view = true;
        if (!$this->sub_views)
            $this->sub_views = array();
        
        $this->sub_views[] = $sub_view;
    }

    protected function prepare_playback_url($series, &$plugin_cookies)    
    {
        return str_ireplace('http://', 'http://mp4://', $series->playback_url);
    }
    protected function get_initial_position($initial_series_ndx, &$plugin_cookies)
    {
        $is_audio = $this->series_list[$initial_series_ndx]->is_audio;
        $resume_audio = isset($plugin_cookies->resume_audio) ? $plugin_cookies->resume_audio : 'no';
        if ($is_audio && $resume_audio == 'no')
            return parent::get_initial_position($initial_series_ndx, $plugin_cookies);

        return $this->series_list[$initial_series_ndx]->watched *1000;
    }

    protected function get_movie_actions($initial_series_ndx, &$plugin_cookies)
    {
        $is_audio = $this->series_list[$initial_series_ndx]->is_audio;
        $resume_audio = isset($plugin_cookies->resume_audio) ? $plugin_cookies->resume_audio : 'no';
        if ($is_audio && $resume_audio == 'no')
            return parent::get_movie_actions($initial_series_ndx, $plugin_cookies);
            
        UserInputHandlerRegistry::get_instance()->
            register_handler($this);

        $actions[GUI_EVENT_PLAYBACK_STOP] =
            UserInputHandlerRegistry::create_action($this, 'postroll_watched');
            
        $play_timer = isset($plugin_cookies->play_timer) ? $plugin_cookies->play_timer : 1000;
        if ($play_timer > 0)
        {
            $actions[GUI_EVENT_TIMER] =
                UserInputHandlerRegistry::create_action($this, 'content_timer');
        }
        
        return $actions;        
    }

    protected function get_movie_timer($initial_series_ndx, &$plugin_cookies)
    {
        $is_audio = $this->series_list[$initial_series_ndx]->is_audio;
        $resume_audio = isset($plugin_cookies->resume_audio) ? $plugin_cookies->resume_audio : 'no';
        if ($is_audio && $resume_audio == 'no')
            return parent::get_movie_timer($initial_series_ndx, $plugin_cookies);

        $play_timer = isset($plugin_cookies->play_timer) ? $plugin_cookies->play_timer : 1000;
        if ($play_timer == 0)
            return false;
        
        return array(GuiTimerDef::delay_ms => $play_timer);        
    }

    public function handle_user_input(&$user_input, &$plugin_cookies)
    {
//        hd_print('movie: handle_user_input:');
//        foreach ($user_input as $key => $value)
//            hd_print("  $key => $value");

        $init_idx = $user_input->plugin_vod_series_ndx;
        if ($init_idx < 0)
            return null;
            
        switch ($user_input->control_id)
        {
        case 'postroll_watched':
            if ($this->series_idx != -1 && !isset($user_input->playback_stop_pressed))
                $init_idx = $this->series_idx;

            $this->series_list[$init_idx]->watched = $this->last_pos;
            UlitkaApi::send_state('stop', $this->series_list[$init_idx]->uid, $this->series_list[$init_idx]->cid, $this->last_pos, $plugin_cookies);
            $this->last_pos = 0;
            
            $this->series_idx = -1;
            return  ActionFactory::invalidate_folders
                    (
                        array
                        (
                            UlitkaVodSeriesListScreen::get_media_url_str($this->id)
                        )
                    );                                
        case 'content_timer': // Watch has started.
            // get position playback
            $ret = shell_exec('cat /tmp/run/ext_command.state | grep playback_position');
            preg_match('/playback_position = (\S*)/', $ret, $matches);
            $pos = intval($matches[1]);
            $this->last_pos = $pos;
            if ($this->series_idx == -1)
            {
                UlitkaApi::send_state('play', $this->series_list[$init_idx]->uid, $this->series_list[$init_idx]->cid, $pos, $plugin_cookies);
            }
            $this->series_idx = $init_idx;
            // get state
            $ret = shell_exec('cat /tmp/run/ext_command.state | grep playback_state');
            preg_match('/playback_state = (\S*)/', $ret, $matches);
            $state = strval($matches[1]);
            if ($state == 'playing')
            {
                if ($this->pause_sent == true)
                    UlitkaApi::send_state('play', $this->series_list[$init_idx]->uid, $this->series_list[$init_idx]->cid, $pos, $plugin_cookies);
                $this->pause_sent = false;
            }
            else if ($state == 'paused')
            {
                if ($this->pause_sent == false)
                {
                    UlitkaApi::send_state('pause', $this->series_list[$init_idx]->uid, $this->series_list[$init_idx]->cid, $pos, $plugin_cookies);
                    $this->pause_sent = true;
                }
            }
            $actions[GUI_EVENT_PLAYBACK_STOP] =
                UserInputHandlerRegistry::create_action($this, 'postroll_watched');
                                           
            $actions[GUI_EVENT_TIMER] =
                UserInputHandlerRegistry::create_action($this, 'content_timer');

            $play_timer = isset($plugin_cookies->play_timer) ? $plugin_cookies->play_timer : 1000;
            
            $data = array
                    (
                        ChangeBehaviourActionData::actions => $actions,
                        ChangeBehaviourActionData::timer => array(GuiTimerDef::delay_ms => $play_timer),
                    );

            $params = array(
                'handler_id' => $this->get_handler_id(),
                'control_id' => 'timer');
            
            return array
            (
                GuiAction::handler_string_id => CHANGE_BEHAVIOUR_ACTION_ID,
                GuiAction::caption => null,
                GuiAction::data => $data,
                GuiAction::params => $params,
            );
        }
        
        return null;
    }
}

?>
