<?php
///////////////////////////////////////////////////////////////////////////
require_once 'lib/list_util.php';

require_once 'lib/vod/abstract_vod.php';

//require_once 'Ulitka_movie.php';

///////////////////////////////////////////////////////////////////////////

class UlitkaVod extends AbstractVod
{
    public $m_feed;

    public $userid = 0;
    public $vip = 0;
    public $category_list;
    public $movies = array();
    
    private $skins;
    private $login;
    
    public function __construct($login, $skins)
    {
        parent::__construct(
            UlitkaConfig::VOD_FAVORITES_SUPPORTED,
            UlitkaConfig::VOD_MOVIE_PAGE_SUPPORTED,
            UlitkaConfig::VOD_SECTION_SEARCH_SUPPORTED,
            true);
            
        $this->skins = $skins;
        $this->login = $login;
    }

    ///////////////////////////////////////////////////////////////////////

    public function try_load_movie($movie_id, &$plugin_cookies)
    {
        $movie = UlitkaApi::get_movie_by_id($movie_id, $plugin_cookies);
        if ($movie)
            $this->set_cached_short_movie($movie);
    }

    public function get_buffering_ms(&$plugin_cookies)
    {
        return isset($plugin_cookies->buf_time) ? $plugin_cookies->buf_time : 0;
    }

    public function get_vod_stream_url($playback_url, &$plugin_cookies)
    {
	    return $playback_url;
    }
    ///////////////////////////////////////////////////////////////////////
    // Favorites.

    protected function load_favorites(&$plugin_cookies)
    {
        $fav_movie_ids = $this->get_fav_movie_ids_from_cookies($plugin_cookies);

        foreach ($fav_movie_ids as $movie_id)
        {
//            if ($this->has_cached_short_movie($movie_id))
//                continue;

            $this->ensure_movie_loaded($movie_id, $plugin_cookies);
        }

        $this->set_fav_movie_ids($fav_movie_ids);
    }

    protected function do_save_favorite_movies(&$fav_movie_ids, &$plugin_cookies)
    {
        $this->set_fav_movie_ids_to_cookies($plugin_cookies, $fav_movie_ids);
    }

    ///////////////////////////////////////////////////////////////////////

    public function get_fav_movie_ids_from_cookies(&$plugin_cookies)
    {
        $items = array();
        
        $fav_items = isset($plugin_cookies->fav_items) ? $plugin_cookies->fav_items : '';

        foreach (ListUtil::string_to_list($fav_items) as $item)
        {
            if ($item !== "")
            {
                $items[] = $item;
            }
        }
        
        return $items;
    }

    public function is_favorite_movie_id($movie_id, $plugin_cookies)
    {
        $fav_items = isset($plugin_cookies->fav_items) ? $plugin_cookies->fav_items : '';

        return ListUtil::is_in_list($fav_items, $movie_id);
    }

    protected function do_add_favorite_movie($movie_id, &$plugin_cookies)
    {
        $fav_items = isset($plugin_cookies->fav_items) ? $plugin_cookies->fav_items : '';
        $plugin_cookies->fav_items = ListUtil::add_item($fav_items, $movie_id);
    }

    protected function do_remove_favorite_movie($movie_id, &$plugin_cookies)
    {
        $fav_items = isset($plugin_cookies->fav_items) ? ListUtil::del_item($plugin_cookies->fav_items, $movie_id) : '';
        $plugin_cookies->fav_items = $fav_items;
    }
    
    public function set_fav_movie_ids_to_cookies(&$plugin_cookies, &$ids)
    {

    }


    ///////////////////////////////////////////////////////////////////////
    // Search.

    public function get_section_search_url($media_url, &$plugin_cookies)
    {
    }
    public function get_search_history_media_url_str($cat_id, $pattern = '')
    {
        return UlitkaVodListScreen::get_media_url_str('search', false, $pattern);
    }
/*
    public function get_search_media_url_str($pattern)
    {
        return UlitkaVodListScreen::get_media_url_str('search', $pattern);
    }
*/

    public function ensure_movie_loaded($movie_id, &$plugin_cookies)
    {
        if (!isset($movie_id))
            throw new Exception('Movie ID is not set');

        if ($this->is_failed_movie_id($movie_id))
            return null;

        $movie = $this->get_cached_movie($movie_id);
        if ($movie === null)
            $this->try_load_movie($movie_id, $plugin_cookies);
    }
    
    public function load_full_movie($short_movie, $plugin_cookies)
    {
        $series = false;
        if (UlitkaApi::movie_is_season($short_movie->id, $plugin_cookies))
            $series = UlitkaApi::parse_season($short_movie->ref, $this->userid, $description, $genre, $plugin_cookies);
        else
            UlitkaApi::get_short_movie_info($short_movie->ref, $description, $genre, $plugin_cookies);

        $movie = new UlitkaMovie($short_movie->id);
        $movie->ref = $short_movie->ref;
        
        $movie->set_data
        (
            $short_movie->name,
            '',     // original
            $description,
            $short_movie->poster_url,
            '',
            '',     // year,
            '',     // director
            '',     // scenarios_str
            '',     // actors
            $genre,
            '',     // imdb,
            '',     // kinopoisk
            '',     // $rate_mpaa,
            '',     // country
            ''      // $budget
        );
        if ($series)
        {
            foreach ($series as $s)
            {
                $movie->add_episode($s);
            }
        }
        
        $this->set_cached_movie($movie);
        
        return $movie;
    }
    ///////////////////////////////////////////////////////////////////////
    // Folder views.

    public function get_base_folder_actions($handler, $is_favorites = false)
    {
        $actions = array();
        
        // Search
        $action = UserInputHandlerRegistry::create_action($handler, 'search');
        $action['caption'] = 'Поиск';
        $actions[GUI_EVENT_KEY_B_GREEN] = $action;

        // Autorization
        $action = UserInputHandlerRegistry::create_action($handler, 'change_user');
        $action['caption'] = 'Авторизация (VIP ' . $this->vip . ' дней)';
        $actions[GUI_EVENT_KEY_C_YELLOW] = $action;

        if (!$is_favorites)
        {
            // Settings
            $action = UserInputHandlerRegistry::create_action($handler, 'settings');
            $action['caption'] = 'Настройки плагина';
            $actions[GUI_EVENT_KEY_D_BLUE] = $action;
        }
        else
        {
            // Favorites
            $action = UserInputHandlerRegistry::create_action($handler, 'add_favorite');
            $action['caption'] = 'Добавить в Избранное';
            $actions[GUI_EVENT_KEY_D_BLUE] = $action;
        }
        
        return $actions;
    }
    
    public function handle_base_actions(&$user_input, &$plugin_cookies)
    {
        if ($user_input->control_id == 'search')
        {
            return ActionFactory::open_folder('search_history', 'Поиск');
        }
        else if ($user_input->control_id == 'change_user')
        {
            return ActionFactory::show_dialog("Ulitka.tv - Авторизация", $this->login->get_control_defs($plugin_cookies), true);
        }
        else if ($user_input->control_id == 'settings')
        {
            return ActionFactory::open_folder(UlitkaSetupScreen::get_media_url_str(), "Настройки");
        }
        else if ($user_input->control_id == 'add_favorite')
        {
            if (!isset($user_input->selected_media_url))
                return false;
            $media_url = MediaURL::decode($user_input->selected_media_url);
            $movie_id = $media_url->movie_id;

            $is_favorite = $this->is_favorite_movie_id($movie_id, $plugin_cookies);
            if ($is_favorite)
            {
                return ActionFactory::show_title_dialog('Видео уже в избранном');
            }
            else
            {
                $this->add_favorite_movie($movie_id, $plugin_cookies);
                return ActionFactory::show_title_dialog('Видео добавлено в избранное');
            }
        }
        
        return false;
    }
    
    public function folder_entered(MediaURL $media_url, &$plugin_cookies)
    {

    }
   
    public function get_vod_list_folder_views(&$plugin_cookies)
    {
        return $this->skins->get_current_skin($plugin_cookies)->GET_VOD_MOVIE_LIST_FOLDER_VIEWS($plugin_cookies);
    }

    public function get_vod_search_history_folder_views(&$plugin_cookies)
    {
        return $this->skins->get_current_skin($plugin_cookies)->GET_TEXT_ONE_COL_VIEWS($plugin_cookies);
    }
}

///////////////////////////////////////////////////////////////////////////
?>
