<?php
///////////////////////////////////////////////////////////////////////////

require_once 'lib/abstract_preloaded_regular_screen.php';

require_once 'Ulitka_vod_category.php';
require_once 'Ulitka_vod_list_screen.php';
require_once 'Ulitka_api.php';

///////////////////////////////////////////////////////////////////////////

class UlitkaVodCategoryListScreen extends AbstractPreloadedRegularScreen implements UserInputHandler
{
    const ID = 'vod_category_list';

    public static function get_media_url_str($category_id, $items_count)
    {
        return  MediaURL::encode
                (
                    array
                    (
                        'screen_id'     => self::ID,
                        'category_id'   => $category_id,
                        'items_count'   => $items_count,
                    )
                );
    }

    ///////////////////////////////////////////////////////////////////////

//    private $category_list;
    private $skins;
    private $vod;
    
    ///////////////////////////////////////////////////////////////////////

    public function __construct($vod, $skins)
    {
        parent::__construct(self::ID);
        
        $this->skins = $skins;
        $this->vod = $vod;

        UserInputHandlerRegistry::get_instance()->register_handler($this);
    }

    public function get_handler_id()
    { return self::ID; }
    ///////////////////////////////////////////////////////////////////////

    public function get_action_map(MediaURL $media_url, &$plugin_cookies)
    {
        $actions = $this->vod->get_base_folder_actions($this);

        $actions[GUI_EVENT_KEY_ENTER] = ActionFactory::open_folder();
        
        return $actions;
    }
    
    public function handle_user_input(&$user_input, &$plugin_cookies)
    {
        hd_print('vod_category_list: handle_user_input:');
        foreach ($user_input as $key => $value)
            hd_print("  $key => $value");
            
        return $this->vod->handle_base_actions($user_input, $plugin_cookies);
    }
    ///////////////////////////////////////////////////////////////////////

    public function get_all_folder_items(MediaURL $media_url, &$plugin_cookies)
    {
        if (!isset($this->vod->category_list) || count($this->vod->category_list) == 0)
            $this->fetch_vod_categories($plugin_cookies);

        $category_list = $this->vod->category_list;

        $skin = $this->skins->get_current_skin($plugin_cookies);
      
        $items = array();

        // add favorites
        $category_image = $skin->get_category_image('vod_favorites', $plugin_cookies);
        if (!$category_image)
            $category_image = UlitkaConfig::FAV_MOVIES_CATEGORY_ICON_PATH;
        $items[] = array
        (
            PluginRegularFolderItem::media_url => 'vod_favorites',
            PluginRegularFolderItem::caption => UlitkaConfig::FAV_MOVIES_CATEGORY_CAPTION,
            PluginRegularFolderItem::view_item_params => $skin->get_category_items_view_params('vod_favorites', $category_image, $plugin_cookies),
        );
        
        // add other categories
        foreach ($category_list as $c)
        {
            $media_url_str = UlitkaVodListScreen::get_media_url_str($c->get_id());
            
            $category_image = $skin->get_category_image($c->get_caption(), $plugin_cookies);
            if (!$category_image)
                $category_image = $c->get_image_url();

            $items[] = array
            (
                PluginRegularFolderItem::media_url => $media_url_str,
                PluginRegularFolderItem::caption => $c->get_caption(),
                PluginRegularFolderItem::view_item_params => $skin->get_category_items_view_params($c->get_caption(), $category_image, $plugin_cookies),
            );
        }

        return $items;
    }

    ///////////////////////////////////////////////////////////////////////

    private function fetch_vod_categories(&$plugin_cookies)
    {
        $this->vod->category_list = UlitkaApi::get_categories($plugin_cookies);
    }

    ///////////////////////////////////////////////////////////////////////


    protected function do_get_folder_views(&$plugin_cookies)
    {
        return $this->skins->get_current_skin($plugin_cookies)->GET_VOD_CATEGORY_LIST_FOLDER_VIEWS($plugin_cookies);
    }
}

///////////////////////////////////////////////////////////////////////////
?>
