<?php

require_once 'lib/vod/vod.php';
require_once 'lib/vod/vod_favorites_screen.php';

require_once 'lib/abstract_preloaded_regular_screen.php';
require_once 'lib/list_util.php';

class UlitkaVodFavoritesScreen extends VodFavoritesScreen
{
    public static function get_media_url_str()
    {
        return MediaURL::encode(array('screen_id' => self::ID));
    }

    ///////////////////////////////////////////////////////////////////////
    
    private $skins;

    public function __construct(Vod $vod, $skins)
    {
        parent::__construct($vod);
        
        $this->skins = $skins;
    }

    ///////////////////////////////////////////////////////////////////////

    public function get_action_map(MediaURL $media_url, &$plugin_cookies)
    {
        $actions = $this->vod->get_base_folder_actions($this);

        if ($this->vod->is_movie_page_supported())
            $actions[GUI_EVENT_KEY_ENTER] = ActionFactory::open_folder();
        else
            $actions[GUI_EVENT_KEY_ENTER] = ActionFactory::vod_play();

        $remove_favorite_action =
            UserInputHandlerRegistry::create_action(
                $this, 'remove_favorite');
        $remove_favorite_action['caption'] = 'Удалить';

        $move_fav_top_action = UserInputHandlerRegistry::create_action(
                        $this, 'move_fav_top');
        $move_fav_top_action['caption'] = 'Переместить вверх';

        $menu_items[] = array(
            GuiMenuItemDef::caption => $move_fav_top_action['caption'],
            GuiMenuItemDef::action => $move_fav_top_action);
            
        $menu_items[] = array(
            GuiMenuItemDef::caption => $remove_favorite_action['caption'],
            GuiMenuItemDef::action => $remove_favorite_action);

        $popup_menu_action = ActionFactory::show_popup_menu($menu_items);

        $actions[GUI_EVENT_KEY_POPUP_MENU] = $popup_menu_action;

        return $actions;
    }

    public function handle_user_input(&$user_input, &$plugin_cookies)
    {
        hd_print('Vod favorites: handle_user_input:');
        foreach ($user_input as $key => $value)
            hd_print("  $key => $value");

        $action = $this->vod->handle_base_actions($user_input, $plugin_cookies);
        if ($action)
            return $action;

        if (!isset($user_input->selected_media_url))
            return null;

        $media_url = MediaURL::decode($user_input->selected_media_url);
        $movie_id = $media_url->movie_id;

        if ($user_input->control_id == 'remove_favorite')
        {
            $this->vod->remove_favorite_movie($movie_id, $plugin_cookies);

            return ActionFactory::invalidate_folders(array($user_input->parent_media_url), null);
        }
        else if ($user_input->control_id == 'move_fav_top')
        {
            $fav_items = isset($plugin_cookies->fav_items) ? $plugin_cookies->fav_items : '';
            $plugin_cookies->fav_items = ListUtil::add_item($fav_items,$movie_id);
            $this->vod->reset_favorites($plugin_cookies);
            return ActionFactory::invalidate_folders(array($user_input->parent_media_url), null);
        }
        return null;
    }

    ///////////////////////////////////////////////////////////////////////

    public function get_all_folder_items(MediaURL $media_url, &$plugin_cookies)
    {
        $this->vod->folder_entered($media_url, $plugin_cookies);

        $this->vod->ensure_favorites_loaded($plugin_cookies);

        $movie_ids = $this->vod->get_favorite_movie_ids();

        $view_type = $this->get_folder_view_index($plugin_cookies);

        $skin = $this->skins->get_current_skin($plugin_cookies);

        $items = array();

        foreach ($movie_ids as $movie_id)
        {
            $movie = $this->vod->get_cached_movie($movie_id);
            if (is_null($movie))
                $movie = $this->vod->get_cached_short_movie($movie_id);
            if (is_null($movie))
            {
                $caption = "НЕ НАЙДЕН [#$movie_id]";
                $poster_url = "missing://";

                $items[] = array
                (
                    PluginRegularFolderItem::media_url => UlitkaVodMovieScreen::get_media_url_str($movie_id),
                    PluginRegularFolderItem::caption => $caption,
                    PluginRegularFolderItem::view_item_params => $skin->get_vod_movie_items_view_params
                    (
                        $caption,
                        $poster_url,
                        $view_type,
                        $plugin_cookies
                    )
                );
            }
            else
            {
                if (UlitkaApi::movie_is_season($movie_id, $plugin_cookies))
                    $murl = UlitkaVodListScreen::get_media_url_str('favorites', $movie_id);
                else
                    $murl = UlitkaVodListScreen::get_media_url_str('favorites');
                
                UlitkaVodListScreen::add_movie(MediaURL::decode($murl), $movie, $view_type, $skin, $items, $plugin_cookies);
            }
        }

        return $items;
    }
}

?>
