<?php
///////////////////////////////////////////////////////////////////////////
require_once 'lib/vod/vod_list_screen.php';
require_once 'lib/utils.php';

require_once 'Ulitka_api.php';
require_once 'Ulitka_movie.php';

class UlitkaVodListScreen extends VodListScreen
{
    private $skins;
    
    public static function get_media_url_str($cat_id, $movie_id = false, $search = false, $show_info = true)
    {
        $arr['screen_id'] = self::ID;
        $arr['category_id'] = $cat_id;
        $arr['search'] = $search;
        $arr['movie_id'] = $movie_id;
        $arr['show_info'] = $show_info;
        return MediaURL::encode($arr);
    }

    ///////////////////////////////////////////////////////////////////////

    public function __construct(Vod $vod, $skins)
    {
        parent::__construct($vod);
        
        $this->skins = $skins;
    }

    public function get_action_map(MediaURL $media_url, &$plugin_cookies)
    {
        $actions = $this->vod->get_base_folder_actions($this, $this->vod->is_favorites_supported());

        if ($this->vod->is_movie_page_supported())
            $actions[GUI_EVENT_KEY_ENTER] = ActionFactory::open_folder();
        else
            $actions[GUI_EVENT_KEY_ENTER] = ActionFactory::vod_play();

        return $actions;
        
    }

    public function handle_user_input(&$user_input, &$plugin_cookies)
    {
        hd_print('Vod list: handle_user_input:');
        foreach ($user_input as $key => $value)
            hd_print("  $key => $value");

        $action = $this->vod->handle_base_actions($user_input, $plugin_cookies);
        if ($action)
            return $action;

        return parent::handle_user_input(&$user_input, &$plugin_cookies);
    }
    ///////////////////////////////////////////////////////////////////////
    protected function get_short_movie_range(MediaURL $media_url, $from_ndx, &$plugin_cookies)
    {
        if ($media_url->category_id == 'search')
        {
            return UlitkaApi::get_search_items($media_url->search, $plugin_cookies);
        }
        else if ($media_url->category_id == 'sub_view')
        {
        }
        else
        {
            $category_url = $this->vod->category_list[$media_url->category_id]->get_ref();
            $this->vod->movies[$media_url->category_id] = UlitkaApi::get_short_movies_list($category_url, false, $plugin_cookies);
        }
        
        $nMovies = count($this->vod->movies[$media_url->category_id]);

        return $this->vod->movies[$media_url->category_id];
    }
    public static function add_movie(MediaURL $media_url, $movie, $view_type, $skin, &$items, &$plugin_cookies)
    {
        if (!$media_url->show_info)
            $murl = UlitkaVodSeriesListScreen::get_media_url_str($movie->id);
        else
            $murl = UlitkaVodMovieScreen::get_media_url_str($movie->id);

        $caption = $movie->name;

        $view = array
                (
                    PluginRegularFolderItem::media_url => $murl,
                    PluginRegularFolderItem::caption => $caption,
                );
        if (!$media_url->show_info)
        {
            $view[PluginRegularFolderItem::view_item_params] = $skin->get_vod_seasons_items_view_params
                            (
                                $caption,
                                $movie->poster_url,
                                $plugin_cookies
                            );
        }
        else
        {
            $view[PluginRegularFolderItem::view_item_params] = $skin->get_vod_movie_items_view_params
                            (
                                $caption,
                                $movie->poster_url,
                                $view_type,
                                $plugin_cookies
                            );
        }
        array_push
        (
            $items,
            $view
        );

    }
    public function get_folder_range(MediaURL $media_url, $from_ndx, &$plugin_cookies)
    {
        if ($media_url->category_id === 'search')
        {
            $movie_range = $this->get_short_movie_range($media_url, 0, $plugin_cookies);
        }
        else if (!$media_url->movie_id)
        {
            if (!isset($this->vod->movies[$media_url->category_id]) || count($this->vod->movies[$media_url->category_id]) == 0)
                $movie_range = $this->get_short_movie_range($media_url, 0, $plugin_cookies);
            else
                $movie_range = $this->vod->movies[$media_url->category_id];
        }
        else
        {
            $shmovie = $this->vod->get_cached_short_movie($media_url->movie_id);
            if (is_null($shmovie))
                return HD::create_regular_folder_range(array());

            $movie_range = UlitkaApi::get_seasons($shmovie->ref, $this->vod->userid, $plugin_cookies);
        }
        $total = count($movie_range);
        if ($total < 0)
            return HD::create_regular_folder_range(array());

        $skin = $this->skins->get_current_skin($plugin_cookies);
        $view_type = $this->get_folder_view_index($plugin_cookies);
        
        $total_num = 0;    
        $items = array();
        foreach ($movie_range as $movie)
        {
            ++$total_num;
            
            self::add_movie($media_url, $movie, $view_type, $skin, $items, $plugin_cookies);
            
            if (get_class($movie) == 'ShortMovie')
                $this->vod->set_cached_short_movie($movie);
            else
                $this->vod->set_cached_movie($movie);
        }

        return  HD::create_regular_folder_range
                (
                    $items,
                    0,
                    $total,
                    false
                );
    }

    public function get_folder_view(MediaURL $media_url, &$plugin_cookies)
    {
        $this->vod->m_feed = 0;
        if (!$media_url->show_info)
        {
            $view = $this->skins->get_current_skin($plugin_cookies)->GET_VOD_SEASONS_LIST_FOLDER_VIEWS($plugin_cookies);
            $view = $view[0];
            $view[PluginRegularFolderView::actions] =
                $this->get_action_map($media_url, $plugin_cookies);

            $view[PluginRegularFolderView::initial_range] = 
                $this->get_folder_range($media_url, 0, $plugin_cookies);
            
            return array
            (
                PluginFolderView::multiple_views_supported  => 0,
                PluginFolderView::archive                   => null,
                PluginFolderView::view_kind                 => PLUGIN_FOLDER_VIEW_REGULAR,
                PluginFolderView::data                      => $view
            );
        }
        else
        {
            return parent::get_folder_view($media_url, $plugin_cookies);
        }
    }
}

///////////////////////////////////////////////////////////////////////////
?>
