<?php
///////////////////////////////////////////////////////////////////////////
require_once 'lib/list_util.php';

require_once 'lib/screen.php';
require_once 'lib/vod/vod.php';
require_once 'lib/vod/movie.php';
require_once 'lib/vod/vod_series_list_screen.php';
require_once 'lib/vod/vod_movie_screen.php';

class UlitkaVodMovieScreen extends VodMovieScreen
{
    public static function get_media_url_str($movie_id)
    {
        return MediaURL::encode(
            array(
                'screen_id' => self::ID,
                'movie_id' => $movie_id));
    }

    ///////////////////////////////////////////////////////////////////////

    public function __construct(Vod $vod)
    {
        parent::__construct($vod);
    }

    ///////////////////////////////////////////////////////////////////////
    public function get_folder_view(MediaURL $media_url, &$plugin_cookies)
    {
        $this->vod->folder_entered($media_url, $plugin_cookies);

        $movie = $this->vod->get_loaded_movie($media_url->movie_id, $plugin_cookies);
        if ($movie === null)
        {
            $movie = $this->vod->get_cached_short_movie($media_url->movie_id);
            if ($movie === null)
                return null;
                
            // this is short movie
            if (get_class($movie) == 'ShortMovie')
                $movie = $this->vod->load_full_movie($movie, $plugin_cookies);
            else
                return null;
        }
        

        $has_right_button = true;//$this->vod->is_favorites_supported();
        $right_button_caption = null;
        $right_button_action = null;
        
        $is_favorite = $this->vod->is_favorite_movie_id($media_url->movie_id, $plugin_cookies);
        
        if ($is_favorite)
        {
            $right_button_action = UserInputHandlerRegistry::create_action(
                        $this, 'remove_favorite');
            $right_button_action['caption'] = 'Удалить из Избранного';
        }
        else
        {
            $right_button_action = UserInputHandlerRegistry::create_action(
                        $this, 'add_favorite');
            $right_button_action['caption'] = 'Добавить в Избранное';
        }

        $movie_folder_view = array
        (
            PluginMovieFolderView::movie => $movie->get_movie_array(),
            PluginMovieFolderView::has_right_button => $has_right_button,
            PluginMovieFolderView::right_button_caption => $right_button_action['caption'],
            PluginMovieFolderView::right_button_action => $right_button_action,
            PluginMovieFolderView::has_multiple_series => true,
//                (count($movie->series_list) > 1),
            PluginMovieFolderView::series_media_url =>
                UlitkaVodSeriesListScreen::get_media_url_str($movie->id),
        );
        
        if (!UlitkaApi::movie_is_season($movie->id, $plugin_cookies))
        {
            $movie_folder_view[PluginMovieFolderView::left_button_action] = 
                    ActionFactory::open_folder(UlitkaVodListScreen::get_media_url_str(false, $movie->id, false, false));
        }
           
        return array
        (
            PluginFolderView::multiple_views_supported  => false,
            PluginFolderView::archive                   => null,
            PluginFolderView::view_kind                 => PLUGIN_FOLDER_VIEW_MOVIE,
            PluginFolderView::data                      => $movie_folder_view,
        );
    }

    ///////////////////////////////////////////////////////////////////////
    public function handle_user_input(&$user_input, &$plugin_cookies)
    {
        hd_print('Movie: handle_user_input:');
        foreach ($user_input as $key => $value)
            hd_print("  $key => $value");

        $media_url = MediaURL::decode($user_input->selected_media_url);
        $movie_id = $media_url->movie_id;

        $is_favorite = $this->vod->is_favorite_movie_id($movie_id, $plugin_cookies);
        
        if ($user_input->control_id == 'add_favorite')
        {
            if ($is_favorite)
            {
                return ActionFactory::show_title_dialog('Видео уже в Избранном');
            }
            else
            {
                $this->vod->add_favorite_movie($movie_id, $plugin_cookies);

                return ActionFactory::show_title_dialog('Видео добавлено в избранное');
            }
        }
        else if ($user_input->control_id == 'remove_favorite')
        {
            $this->vod->remove_favorite_movie($movie_id, $plugin_cookies);

            return  ActionFactory::invalidate_folders
                    (
                        array(UlitkaVodFavoritesScreen::get_media_url_str()),
                        ActionFactory::show_title_dialog('Видео было удалено из избранного')
                    );
        }
        return null;
    }
}

///////////////////////////////////////////////////////////////////////////
?>
