<?php
///////////////////////////////////////////////////////////////////////////

require_once 'lib/vod/vod.php';
require_once 'lib/vod/vod_series_list_screen.php';
require_once 'lib/abstract_preloaded_regular_screen.php';
require_once 'lib/list_util.php';
require_once 'lib/utils.php';


class UlitkaVodSeriesListScreen extends VodSeriesListScreen implements UserInputHandler
{
    public static function get_media_url_str($movie_id)
    {
        return MediaURL::encode(
            array(
                'screen_id' => self::ID,
                'movie_id' => $movie_id));
    }

    ///////////////////////////////////////////////////////////////////////

    public function __construct(Vod $vod)
    {
        parent::__construct($vod);

        UserInputHandlerRegistry::get_instance()->register_handler($this);
    }

    ///////////////////////////////////////////////////////////////////////

    public function get_handler_id()
    { return self::ID; }

    public function get_all_folder_items(MediaURL $media_url, &$plugin_cookies)
    {
        $this->vod->folder_entered($media_url, $plugin_cookies);

        $movie = $this->vod->get_loaded_movie($media_url->movie_id, $plugin_cookies);
        if ($movie === null)
        {
            $movie = $this->vod->get_cached_short_movie($media_url->movie_id);
            if ($movie === null)
                return array();
        }
        
        if (get_class($movie) == 'ShortMovie')
            $movie = $this->vod->load_full_movie($movie, $plugin_cookies);
            
        $resume_audio = isset($plugin_cookies->resume_audio) ? $plugin_cookies->resume_audio : 'no';

        $items = array();

        foreach ($movie->series_list as $series)
        {
            $caption = '';
            $movie_id = $movie->id;

            if ($series->watched > 0)
            {
                $caption = '[ПРОСМ ' . HD::format_duration(intval($series->watched) * 1000) . '/' . HD::format_duration(intval($series->duration) * 1000) . '] ';
            }
            else if ($series->is_new)
            {
                $caption = '[НОВАЯ] ';
            }
            
            $caption = $caption . $series->name;

            $items[] = array
            (
                PluginRegularFolderItem::media_url =>
                    MediaURL::encode(
                        array
                        (
                            'screen_id' => self::ID,
                            'movie_id' => $movie->id,
                            'series_id'  => $series->id,
                        )),
                PluginRegularFolderItem::caption => $caption,
                PluginRegularFolderItem::view_item_params => array
                (
                    ViewItemParams::icon_path => 'gui_skin://small_icons/movie.aai',
                ),
            );
        }

        return $items;
    }

    public function get_action_map(MediaURL $media_url, &$plugin_cookies)
    {
        $actions = $this->vod->get_base_folder_actions($this);
        
        $actions[GUI_EVENT_KEY_ENTER] = ActionFactory::vod_play();
        $actions[GUI_EVENT_KEY_PLAY] = ActionFactory::vod_play();
        
        return  $actions;
    }

    public function handle_user_input(&$user_input, &$plugin_cookies)
    {
        hd_print('vod_series_list: handle_user_input:');
        foreach ($user_input as $key => $value)
            hd_print("  $key => $value");
            
        $action = $this->vod->handle_base_actions($user_input, $plugin_cookies);
        if ($action)
            return $action;

        return null;
    }
}

///////////////////////////////////////////////////////////////////////////
?>
