<?php

class ShortMovie
{
    public $id;
    public $name;
    public $ref;
    public $poster_url;

    public function __construct($id, $name, $ref, $poster_url)
    {
        if (is_null($id))
            throw new Exception("ShortMovie::id is null");

        $this->id = strval($id);
        $this->name = strval($name);
	$this->ref = strval($ref);
        $this->poster_url = strval($poster_url);
    }
}

class ShortMovieRange
{
    public $from_ndx;
    public $total;
    public $short_movies;

    public function __construct($from_ndx, $total, $short_movies = null)
    {
        $this->from_ndx = intval($from_ndx);
        $this->total = intval($total);
        $this->short_movies = $short_movies === null ?
            array() : $short_movies;
    }
}

class MovieSeries
{
    public $id;

    public function __construct($id)
    {
        if (is_null($id))
            throw new Exception("MovieSeries::id is null");

        $this->id = strval($id);
    }

    public $name = '';
    public $playback_url = '';
    public $playback_url_is_stream_url = true;
}

class Movie
{
    public $id;
    public $name = '';
    public $ref = '';
    public $name_original = '';
    public $description = '';
    public $poster_url = '';
    public $length_min = -1;
    public $year = 0;
    public $directors_str = '';
    public $scenarios_str = '';
    public $actors_str = '';
    public $genres_str = '';
    public $rate_imdb = '';
    public $rate_kinopoisk = '';
    public $rate_mpaa = '';
    public $country = '';
    public $budget = '';

    public $series_list = null;

    public $preplay_url;
    public $postplay_url;

    public function __construct($id)
    {
        if (is_null($id))
            throw new Exception("Movie::id is null");

        $this->id = strval($id);
    }

    private function to_string($v)
    {
        return $v === null ? '' : strval($v);
    }

    private function to_int($v, $default_value)
    {
        $v = strval($v);
        if (!is_numeric($v))
            return $default_value;
        $v = intval($v);
        return $v <= 0 ? $default_value : $v;
    }

    public function set_data(
        $name,
        $name_original,
        $description,
        $poster_url,
        $length_min,
        $year,
        $directors_str,
        $scenarios_str,
        $actors_str,
        $genres_str,
        $rate_imdb,
        $rate_kinopoisk,
        $rate_mpaa,
        $country,
        $budget)
    {
        $this->name = $this->to_string($name);
        $this->name_original = $this->to_string($name_original);
        $this->description = $this->to_string($description);
        $this->poster_url = $this->to_string($poster_url);
        $this->length_min = $this->to_int($length_min, -1);
        $this->year = $this->to_int($year, -1);
        $this->directors_str = $this->to_string($directors_str);
        $this->scenarios_str = $this->to_string($scenarios_str);
        $this->actors_str = $this->to_string($actors_str);
        $this->genres_str = $this->to_string($genres_str);
        $this->rate_imdb = $this->to_string($rate_imdb);
        $this->rate_kinopoisk = $this->to_string($rate_kinopoisk);
        $this->rate_mpaa = $this->to_string($rate_mpaa);
        $this->country = $this->to_string($country);
        $this->budget = $this->to_string($budget);

        $this->series_list = array();
    }

    public function add_series_data($id, $name,
        $playback_url, $playback_url_is_stream_url)
    {
        $series = new MovieSeries($id);

        $series->name = $this->to_string($name);
        $series->playback_url = $this->to_string($playback_url);
        $series->playback_url_is_stream_url =
            $playback_url_is_stream_url === true;

        $this->series_list[] = $series;
    }

    public function set_advert_urls($preplay_url, $postplay_url)
    {
        $this->preplay_url = isset($preplay_url) ?
            strval($preplay_url) : null;
        $this->postplay_url = isset($postplay_url) ?
            strval($postplay_url) : null;
    }

    public function get_movie_array()
    {
        return array(
            PluginMovie::name => $this->name,
            PluginMovie::name_original => $this->name_original,
            PluginMovie::description => $this->description,
            PluginMovie::poster_url => $this->poster_url,
            PluginMovie::length_min => $this->length_min,
            PluginMovie::year => $this->year,
            PluginMovie::directors_str => $this->directors_str,
            PluginMovie::scenarios_str => $this->scenarios_str,
            PluginMovie::actors_str => $this->actors_str,
            PluginMovie::genres_str => $this->genres_str,
            PluginMovie::rate_imdb => $this->rate_imdb,
            PluginMovie::rate_kinopoisk => $this->rate_kinopoisk,
            PluginMovie::rate_mpaa => $this->rate_mpaa,
            PluginMovie::country => $this->country,
            PluginMovie::budget => $this->budget
        );
    }

    public function get_postplay_vod_info()
    {
        if (!isset($this->postplay_url))
            return null;

        $series_array[] = array(
            PluginVodSeriesInfo::name => "series1",
            PluginVodSeriesInfo::playback_url => $this->postplay_url,
            PluginVodSeriesInfo::playback_url_is_stream_url => true,
        );

        return array(
            PluginVodInfo::name => "series1",
            PluginVodInfo::series => $series_array,
            PluginVodInfo::advert_mode => true,
            PluginVodInfo::initial_position_ms => 0,
        );
    }

    protected function get_initial_position($initial_series_ndx, &$plugin_cookies)
    {
        return 0;
    }

    protected function get_movie_actions($initial_series_ndx, &$plugin_cookies)
    {
        $actions[GUI_EVENT_PLAYBACK_STOP] =
            ActionFactory::vod_play(
                $this->get_postplay_vod_info());
        
        return $actions;        
    }

    protected function get_movie_timer($initial_series_ndx, &$plugin_cookies)
    {
        return false;
    }

    protected function prepare_playback_url($series, &$plugin_cookies)    
    {
        return $series->playback_url;
    }
    
    public function get_main_vod_info($sel_id, $buffering_ms, &$plugin_cookies)
    {
        if (!is_array($this->series_list) ||
            count($this->series_list) == 0)
        {
            throw new Exception('Invalid movie: series list is empty');
        }

        $series_array = array();
        $initial_series_ndx = 0;
        foreach ($this->series_list as $ndx => $series)
        {
            if (!is_null($sel_id) && $series->id === $sel_id)
                $initial_series_ndx = $ndx;

            $series_array[] = array(
                PluginVodSeriesInfo::name => $series->name,
                PluginVodSeriesInfo::playback_url => $this->prepare_playback_url($series, $plugin_cookies),
                PluginVodSeriesInfo::playback_url_is_stream_url =>
                    $series->playback_url_is_stream_url,
            );
        }

        $timer = $this->get_movie_timer($initial_series_ndx, $plugin_cookies);
        if (!$timer)
        {
            return  array
                    (
                        PluginVodInfo::id => $this->id,
                        PluginVodInfo::name => $this->name,
                        PluginVodInfo::description => $this->description,
                        PluginVodInfo::poster_url => $this->poster_url,
                        PluginVodInfo::series => $series_array,
                        PluginVodInfo::initial_series_ndx => $initial_series_ndx,
                        PluginVodInfo::buffering_ms => $buffering_ms,
                        PluginVodInfo::advert_mode => false,
                        PluginVodInfo::actions => $this->get_movie_actions($initial_series_ndx, $plugin_cookies),
                        PluginVodInfo::initial_position_ms => $this->get_initial_position($initial_series_ndx, $plugin_cookies),
                    );
        }
        else
        {
            return  array
                    (
                        PluginVodInfo::id => $this->id,
                        PluginVodInfo::name => $this->name,
                        PluginVodInfo::description => $this->description,
                        PluginVodInfo::poster_url => $this->poster_url,
                        PluginVodInfo::series => $series_array,
                        PluginVodInfo::initial_series_ndx => $initial_series_ndx,
                        PluginVodInfo::buffering_ms => $buffering_ms,
                        PluginVodInfo::advert_mode => false,
                        PluginVodInfo::actions => $this->get_movie_actions($initial_series_ndx, $plugin_cookies),
                        PluginVodInfo::initial_position_ms => $this->get_initial_position($initial_series_ndx, $plugin_cookies),
                        PluginVodInfo::timer => $timer,
                    );
        }
    }

    public function get_preplay_vod_info($sel_id, $buffering_ms)
    {
        if (!isset($this->preplay_url))
            return null;

        $series_array[] = array(
            PluginVodSeriesInfo::name => "series1",
            PluginVodSeriesInfo::playback_url => $this->preplay_url,
            PluginVodSeriesInfo::playback_url_is_stream_url => true,
        );

        $actions[GUI_EVENT_PLAYBACK_STOP] =
            ActionFactory::vod_play(
                $this->get_main_vod_info($sel_id, $buffering_ms));

        return array(
            PluginVodInfo::name => "series1",
            PluginVodInfo::series => $series_array,
            PluginVodInfo::advert_mode => true,
            PluginVodInfo::actions => $actions,
            PluginVodInfo::initial_position_ms => 0,
        );
    }

    public function get_vod_info($sel_id, $buffering_ms, &$plugin_cookies)
    {
        $info = $this->get_preplay_vod_info($sel_id, $buffering_ms);
        if (isset($info))
            return $info;

        return $this->get_main_vod_info($sel_id, $buffering_ms, $plugin_cookies);
    }
}

?>
